@@ -9,15 +9,15 @@
  * Copyright 1999-2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -32,14 +32,13 @@
 #include <sys/stat.h>
 
 #include "camel-debug.h"
-
+#include "camel-exception.h"
+#include "camel-folder.h"
+#include "camel-i18n.h"
+#include "camel-private.h"
 #include "camel-session.h"
 #include "camel-store.h"
-#include "camel-folder.h"
 #include "camel-vtrash-folder.h"
-#include "camel-exception.h"
-#include "camel-private.h"
-#include "camel-i18n.h"
 
 #define d(x)
 #define w(x)
@@ -287,6 +286,16 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 			camel_object_trigger_event(store, "folder_opened", folder);
 	}
 
+	if (camel_debug_start(":store")) {
+		char *u = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_PASSWORD);
+
+		printf("CamelStore('%s'):get_folder('%s', %u) = %p\n", u, folder_name, flags, folder);
+		if (ex && ex->id)
+			printf("  failed: '%s'\n", ex->desc);
+		g_free(u);
+		camel_debug_end();
+	}
+
 	return folder;
 }
 
@@ -429,7 +438,7 @@ camel_store_rename_folder (CamelStore *store, const char *old_namein, const char
 {
 	CamelFolder *folder;
 	int i, oldlen, namelen;
-	GPtrArray *folders;
+	GPtrArray *folders = NULL;
 	char *old_name;
 
 	d(printf("store rename folder %s '%s' '%s'\n", ((CamelService *)store)->url->protocol, old_name, new_name));
@@ -476,7 +485,7 @@ camel_store_rename_folder (CamelStore *store, const char *old_namein, const char
 	CS_CLASS (store)->rename_folder (store, old_name, new_name, ex);
 
 	/* If it worked, update all open folders/unlock them */
-	if (!camel_exception_is_set(ex)) {
+	if (folders && !camel_exception_is_set(ex)) {
 		guint32 flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE;
 		CamelRenameInfo reninfo;
 
