@@ -38,7 +38,6 @@
 #include "camel-imap-folder.h"
 #include "camel-imap-store.h"
 #include "camel-imap-store-summary.h"
-#include "camel-imap-private.h"
 #include <camel/camel-exception.h>
 #include <camel/camel-private.h>
 #include <camel/camel-utf8.h>
@@ -439,10 +438,9 @@ imap_read_untagged (CamelImapStore *store, char *line, CamelException *ex)
 		fulllen += str->len;
 		g_ptr_array_add (data, str);
 		
-		p = strrchr (str->str, '{');
-		if (!p)
+		if (!(p = strrchr (str->str, '{')) || p[1] == '-')
 			break;
-
+		
 		/* HACK ALERT: We scan the non-literal part of the string, looking for possible s expression braces.
 		   This assumes we're getting s-expressions, which we should be.
 		   This is so if we get a blank line after a literal, in an s-expression, we can keep going, since
